@@ -78,7 +78,16 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
 
     if (fromView) {
         m_type = clip4;
-        UMLScene *scene = UMLApp::app()->currentView()->umlScene();
+        UMLView *view = UMLApp::app()->currentView();
+        if (view == NULL) {
+            uError() << "UMLApp::app()->currentView() is NULL";
+            return NULL;
+        }
+        UMLScene *scene = view->umlScene();
+        if (scene == NULL) {
+            uError() << "currentView umlScene() is NULL";
+            return NULL;
+        }
         scene->checkSelections();
         m_WidgetList = scene->selectedWidgetsExt();
         //if there is no selected widget then there is no copy action
@@ -305,9 +314,9 @@ void UMLClipboard::setCopyType(UMLListViewItemList& selectedItems)
     foreach (UMLListViewItem* item, selectedItems) {
         checkItemForCopyType(item, withDiagrams, withObjects, onlyAttsOps);
     }
-    if(onlyAttsOps) {
+    if (onlyAttsOps) {
         m_type = clip5;
-    } else if(withDiagrams) {
+    } else if (withDiagrams) {
         m_type = clip2;
     } else if(withObjects) {
         m_type = clip1;
@@ -342,7 +351,10 @@ void UMLClipboard::checkItemForCopyType(UMLListViewItem* item, bool & withDiagra
         withDiagrams = true;
         onlyAttsOps = false;
         view = doc->findView(item->ID());
-        m_ViewList.append(view);
+        if (view)
+            m_ViewList.append(view);
+        else
+            uError() << "doc->findView(" << Uml::ID::toString(item->ID()) << ") returns NULL";
     } else if (Model_Utils::typeIsFolder(type)) {
         onlyAttsOps = false;
         for (int i =0; i < item->childCount(); i++) {
