@@ -29,8 +29,7 @@ class CodeViewerDialog : public KDialog, private Ui::CodeViewerDialogBase
     Q_OBJECT
 public:
 
-    CodeViewerDialog (QWidget* parent, CodeDocument * doc, Settings::CodeViewerState state,
-                       const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    CodeViewerDialog (QWidget* parent, CodeDocument * doc, Settings::CodeViewerState state);
 
     ~CodeViewerDialog ();
 
@@ -48,7 +47,7 @@ private:
 
     Settings::CodeViewerState m_state;
 
-    void initGUI (const char * name);
+    void initGUI();
 
 public slots:
 
