@@ -23,8 +23,6 @@
 // qt includes
 #include <QPainter>
 
-#define CIRCLE_SIZE 30
-
 /**
  * Constructs an DatatypeWidget.
  *
@@ -49,9 +47,6 @@ DatatypeWidget::~DatatypeWidget()
  */
 void DatatypeWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
-    Q_UNUSED(option);
-    Q_UNUSED(widget);
-
     setPenFromSettings(painter);
     if (UMLWidget::useFillColor())  {
         painter->setBrush(UMLWidget::fillColor());
@@ -96,7 +91,7 @@ bool DatatypeWidget::loadFromXMI(QDomElement & qElement)
  */
 void DatatypeWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
 {
-    QDomElement conceptElement = qDoc.createElement("datatypewidget");
+    QDomElement conceptElement = qDoc.createElement(QLatin1String("datatypewidget"));
     UMLWidget::saveToXMI(qDoc, conceptElement);
     qElement.appendChild(conceptElement);
 }
@@ -104,7 +99,7 @@ void DatatypeWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
 /**
  * Overrides method from UMLWidget.
  */
-QSizeF DatatypeWidget::minimumSize()
+QSizeF DatatypeWidget::minimumSize() const
 {
     if (!m_umlObject)  {
         return UMLWidget::minimumSize();
